==> evolution-3.5.92.tar.xz: evolution-3.5.92/e-util/e-file-request.h <==
/*
 * e-file-request.h
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with the program; if not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef E_FILE_REQUEST_H
#define E_FILE_REQUEST_H

#define LIBSOUP_USE_UNSTABLE_REQUEST_API

#include <libsoup/soup.h>
#include <libsoup/soup-request.h>

/* Standard GObject macros */
#define E_TYPE_FILE_REQUEST \
	(e_file_request_get_type ())
#define E_FILE_REQUEST(obj) \
	(G_TYPE_CHECK_INSTANCE_CAST \
	((obj), E_TYPE_FILE_REQUEST, EFileRequest))
#define E_FILE_REQUEST_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_CAST \
	((cls), E_TYPE_FILE_REQUEST, EFileRequestClass))
#define E_IS_FILE_REQUEST(obj) \
	(G_TYPE_CHECK_INSTANCE_TYPE \
	((obj), E_TYPE_FILE_REQUEST))
#define E_IS_FILE_REQUEST_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_TYPE \
	((cls), E_TYPE_FILE_REQUEST))
#define E_FILE_REQUEST_GET_CLASS(obj) \
	(G_TYPE_INSTANCE_GET_CLASS \
	((obj), E_TYPE_FILE_REQUEST, EFileRequestClass))

G_BEGIN_DECLS

typedef struct _EFileRequest EFileRequest;
typedef struct _EFileRequestClass EFileRequestClass;
typedef struct _EFileRequestPrivate EFileRequestPrivate;

struct _EFileRequest {
	SoupRequest parent;
	EFileRequestPrivate *priv;
};

struct _EFileRequestClass {
	SoupRequestClass parent;
};

GType		e_file_request_get_type		(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_FILE_REQUEST_H */

==> evolution_3.10.4.orig.tar.xz: evolution-3.10.4/e-util/e-file-request.h <==
/*
 * e-file-request.h
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with the program; if not, see <http://www.gnu.org/licenses/>
 *
 */

#if !defined (__E_UTIL_H_INSIDE__) && !defined (LIBEUTIL_COMPILATION)
#error "Only <e-util/e-util.h> should be included directly."
#endif

#ifndef E_FILE_REQUEST_H
#define E_FILE_REQUEST_H

#define LIBSOUP_USE_UNSTABLE_REQUEST_API

#include <libsoup/soup.h>
#include <libsoup/soup-request.h>

/* Standard GObject macros */
#define E_TYPE_FILE_REQUEST \
	(e_file_request_get_type ())
#define E_FILE_REQUEST(obj) \
	(G_TYPE_CHECK_INSTANCE_CAST \
	((obj), E_TYPE_FILE_REQUEST, EFileRequest))
#define E_FILE_REQUEST_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_CAST \
	((cls), E_TYPE_FILE_REQUEST, EFileRequestClass))
#define E_IS_FILE_REQUEST(obj) \
	(G_TYPE_CHECK_INSTANCE_TYPE \
	((obj), E_TYPE_FILE_REQUEST))
#define E_IS_FILE_REQUEST_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_TYPE \
	((cls), E_TYPE_FILE_REQUEST))
#define E_FILE_REQUEST_GET_CLASS(obj) \
	(G_TYPE_INSTANCE_GET_CLASS \
	((obj), E_TYPE_FILE_REQUEST, EFileRequestClass))

G_BEGIN_DECLS

typedef struct _EFileRequest EFileRequest;
typedef struct _EFileRequestClass EFileRequestClass;
typedef struct _EFileRequestPrivate EFileRequestPrivate;

struct _EFileRequest {
	SoupRequest parent;
	EFileRequestPrivate *priv;
};

struct _EFileRequestClass {
	SoupRequestClass parent;
};

GType		e_file_request_get_type		(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_FILE_REQUEST_H */
